Learn R Programming

messy.cats (version 1.0)

typos: typos

Description

Data set of words, some correctly spelled, some typos, with their occurrence in text

Usage

typos

Arguments

Format

A data frame with 27 rows and 2 variables:

occurrence

double number of times word appears in text

species

character words in text

Details

An example data set that can be used in testing fix_typos().