powered by
Uses heuristic algorithm to suggest a stringdist metric from among hamming, lv, osa, dl, lcs, jw
select_metric(messy_v, clean_v)
a string representing the suggested stringdist metric
a messy vector of strings
a vector of strings for messy_v to be matched against
for each metric, measures certainty via the difference between the best matches for each word and the average of all matches for each word
stringdist
select_metric(c("aapple", "bamana", "clemtidne"), c("apple", "banana", "clementine"))
Run the code above in your browser using DataLab